summaryrefslogtreecommitdiffstats
path: root/ash/system/tray/system_tray_delegate.h
diff options
context:
space:
mode:
Diffstat (limited to 'ash/system/tray/system_tray_delegate.h')
-rw-r--r--ash/system/tray/system_tray_delegate.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/ash/system/tray/system_tray_delegate.h b/ash/system/tray/system_tray_delegate.h
index 82644f03f..144e41a 100644
--- a/ash/system/tray/system_tray_delegate.h
+++ b/ash/system/tray/system_tray_delegate.h
@@ -217,8 +217,8 @@ class SystemTrayDelegate {
// Requests bluetooth stop discovering devices.
virtual void BluetoothStopDiscovering() = 0;
- // Toggles connection to a specific bluetooth device.
- virtual void ToggleBluetoothConnection(const std::string& address) = 0;
+ // Connect to a specific bluetooth device.
+ virtual void ConnectToBluetoothDevice(const std::string& address) = 0;
// Returns true if bluetooth adapter is discovering bluetooth devices.
virtual bool IsBluetoothDiscovering() = 0;